==> react-bootstrap-0.2.0.tgz: package/es/components/ButtonWithConfirm/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp2;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component, Fragment } from 'react';
import PropTypes from 'prop-types';

import Button from '../Button';
import ButtonWithLoader from '../ButtonWithLoader';
import PopupWithCard from '../PopupWithCard';

import buttonColors from '../../utils/buttonColors';

var ButtonWithConfirm = (_temp2 = _class = function (_Component) {
  _inherits(ButtonWithConfirm, _Component);

  function ButtonWithConfirm() {
    var _temp, _this, _ret;

    _classCallCheck(this, ButtonWithConfirm);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _Component.call.apply(_Component, [this].concat(args))), _this), _this.state = {
      showConfirmPopup: false
    }, _this.isUnmounted = false, _this.handleClick = function (e) {
      _this.toggleConfirmPopup();
      _this.props.onClick(e);
    }, _this.handleConfirm = function () {
      return Promise.resolve().then(_this.props.onConfirm).then(_this.toggleConfirmPopup);
    }, _this.toggleConfirmPopup = function () {
      return !_this.isUnmounted && _this.setState({
        showConfirmPopup: !_this.state.showConfirmPopup
      });
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  ButtonWithConfirm.prototype.componentWillUnmount = function componentWillUnmount() {
    this.isUnmounted = true;
  };

  ButtonWithConfirm.prototype.render = function render() {
    var _props = this.props,
        confirmMessage = _props.confirmMessage,
        confirmButtonText = _props.confirmButtonText,
        confirmButtonColor = _props.confirmButtonColor,
        cancelButtonText = _props.cancelButtonText,
        onClick = _props.onClick,
        onConfirm = _props.onConfirm,
        props = _objectWithoutProperties(_props, ['confirmMessage', 'confirmButtonText', 'confirmButtonColor', 'cancelButtonText', 'onClick', 'onConfirm']);

    var showConfirmPopup = this.state.showConfirmPopup;


    return React.createElement(
      Fragment,
      null,
      React.createElement(Button, _extends({}, props, { onClick: this.handleClick })),
      showConfirmPopup ? React.createElement(
        PopupWithCard,
        {
          key: 'popup',
          footer: React.createElement(
            'div',
            null,
            React.createElement(
              ButtonWithLoader,
              { color: confirmButtonColor, onClick: this.handleConfirm },
              confirmButtonText
            ),
            React.createElement(
              Button,
              { color: 'light', className: 'ml-1', onClick: this.toggleConfirmPopup },
              cancelButtonText
            )
          ),
          className: 'text-left',
          onClose: this.toggleConfirmPopup
        },
        confirmMessage
      ) : null
    );
  };

  return ButtonWithConfirm;
}(Component), _class.defaultProps = {
  confirmMessage: 'Are you sure?',
  confirmButtonText: 'Ok',
  confirmButtonColor: 'primary',
  cancelButtonText: 'Cancel',
  onClick: function onClick() {},
  onConfirm: function onConfirm() {}
}, _temp2);
ButtonWithConfirm.propTypes = process.env.NODE_ENV !== "production" ? {
  confirmMessage: PropTypes.string,
  confirmButtonText: PropTypes.string,
  confirmButtonColor: PropTypes.oneOf(buttonColors),
  cancelButtonText: PropTypes.string,
  onClick: PropTypes.func,
  onConfirm: PropTypes.func
} : {};


export default ButtonWithConfirm;

==> react-bootstrap-0.2.2.tgz: package/es/components/ButtonWithConfirm/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp2;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component, Fragment } from 'react';
import PropTypes from 'prop-types';

import Button from '../Button';
import ButtonWithLoader from '../ButtonWithLoader';
import PopupWithCard from '../PopupWithCard';

import buttonColors from '../../utils/buttonColors';

var ButtonWithConfirm = (_temp2 = _class = function (_Component) {
  _inherits(ButtonWithConfirm, _Component);

  function ButtonWithConfirm() {
    var _temp, _this, _ret;

    _classCallCheck(this, ButtonWithConfirm);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _Component.call.apply(_Component, [this].concat(args))), _this), _this.state = {
      showConfirmPopup: false
    }, _this.isUnmounted = false, _this.handleClick = function (e) {
      _this.toggleConfirmPopup();
      _this.props.onClick(e);
    }, _this.handleConfirm = function () {
      return Promise.resolve().then(_this.props.onConfirm).then(_this.toggleConfirmPopup);
    }, _this.toggleConfirmPopup = function () {
      return !_this.isUnmounted && _this.setState(function (state) {
        return {
          showConfirmPopup: !state.showConfirmPopup
        };
      });
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  ButtonWithConfirm.prototype.componentWillUnmount = function componentWillUnmount() {
    this.isUnmounted = true;
  };

  ButtonWithConfirm.prototype.render = function render() {
    var _props = this.props,
        confirmMessage = _props.confirmMessage,
        confirmButtonText = _props.confirmButtonText,
        confirmButtonColor = _props.confirmButtonColor,
        cancelButtonText = _props.cancelButtonText,
        onClick = _props.onClick,
        onConfirm = _props.onConfirm,
        props = _objectWithoutProperties(_props, ['confirmMessage', 'confirmButtonText', 'confirmButtonColor', 'cancelButtonText', 'onClick', 'onConfirm']);

    var showConfirmPopup = this.state.showConfirmPopup;


    return React.createElement(
      Fragment,
      null,
      React.createElement(Button, _extends({}, props, { onClick: this.handleClick })),
      showConfirmPopup ? React.createElement(
        PopupWithCard,
        {
          footer: React.createElement(
            'div',
            null,
            React.createElement(
              ButtonWithLoader,
              { color: confirmButtonColor, onClick: this.handleConfirm },
              confirmButtonText
            ),
            React.createElement(
              Button,
              { color: 'light', className: 'ml-1', onClick: this.toggleConfirmPopup },
              cancelButtonText
            )
          ),
          className: 'text-left',
          onClose: this.toggleConfirmPopup
        },
        confirmMessage
      ) : null
    );
  };

  return ButtonWithConfirm;
}(Component), _class.defaultProps = {
  confirmMessage: 'Are you sure?',
  confirmButtonText: 'Ok',
  confirmButtonColor: 'primary',
  cancelButtonText: 'Cancel',
  onClick: function onClick() {},
  onConfirm: function onConfirm() {}
}, _temp2);
ButtonWithConfirm.propTypes = process.env.NODE_ENV !== "production" ? {
  confirmMessage: PropTypes.string,
  confirmButtonText: PropTypes.string,
  confirmButtonColor: PropTypes.oneOf(buttonColors),
  cancelButtonText: PropTypes.string,
  onClick: PropTypes.func,
  onConfirm: PropTypes.func
} : {};


export default ButtonWithConfirm;
